@@ -3,7 +3,7 @@ BEGIN {
   $SyForm::Field::Verify::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: Required field
-$SyForm::Field::Verify::VERSION = '0.006';
+$SyForm::Field::Verify::VERSION = '0.007';
 use Moose::Role;
 use namespace::autoclean;
 
@@ -31,6 +31,13 @@ has no_delete_on_invalid_result => (
   default => sub { 0 },
 );
 
+around values_roles_by_process_args => sub {
+  my ( $orig, $self, %args ) = @_;
+  return $self->$orig(%args), qw(
+    SyForm::Values::Verify
+  );
+};
+
 around results_roles_by_values => sub {
   my ( $orig, $self, $values ) = @_;
   return $self->$orig($values), qw(
@@ -41,16 +48,14 @@ around results_roles_by_values => sub {
 
 around viewfield_roles_by_results => sub {
   my ( $orig, $self, $results ) = @_;
-  return $self->$orig($results), qw(
-    SyForm::ViewField::Verify
-  );
+  return $self->$orig($results), qw( SyForm::ViewField::Verify ),
+    $self->syform->verify_without_errors ? () : (qw( SyForm::ViewField::Errors ));
 };
 
 around view_roles_by_results => sub {
   my ( $orig, $self, $results ) = @_;
-  return $self->$orig($results), qw(
-    SyForm::View::Success
-  );
+  return $self->$orig($results), qw( SyForm::View::Success ),
+    $self->syform->verify_without_errors ? () : (qw( SyForm::View::Errors ));
 };
 
 1;
@@ -65,7 +70,7 @@ SyForm::Field::Verify - Required field
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 AUTHOR
 
